import React, { useState, useEffect, useCallback } from "react";
import { useNavigate } from "react-router-dom";
import { Button, Typography, Grid, Tooltip } from "@mui/material";
import { useDeleteIOC } from "../../../api/SwaggerApi";
import { SimpleAccordion, ConfirmationDialog } from "@ess-ics/ce-ui-common";
import Alert from "@mui/material/Alert";
import AccessControl from "../../auth/AccessControl";

export default function IOCDelete({ ioc, buttonDisabled }) {
  const navigate = useNavigate();

  function onError(message) {
    setError(message);
  }

  // for the dialog
  const [error, setError] = useState();
  const [open, setOpen] = useState(false);

  const [response, deleteIOC] = useDeleteIOC(ioc.id, onError);

  useEffect(() => {
    if (response && !error) {
      navigate(-1);
    }
  }, [response, navigate, error]);

  let disabledButtonTitle = "";

  if (buttonDisabled || ioc.operationInProgress) {
    disabledButtonTitle =
      "There is an ongoing operation, you can not delete the IOC right now";
  }

  const onClose = useCallback(() => {
    setOpen(false);
  }, [setOpen]);

  const onConfirm = useCallback(() => {
    deleteIOC();
  }, [deleteIOC]);

  return (
    <>
      <ConfirmationDialog
        title="Deleting IOC"
        description={
          <>
            <Typography component="span">
              Are you sure want to delete
              <Typography
                component="span"
                fontFamily="monospace"
              >
                {" "}
                {ioc.namingName}
              </Typography>{" "}
              ?
            </Typography>
          </>
        }
        confirmText="Delete IOC"
        cancelText="Cancel"
        open={open}
        onClose={onClose}
        onConfirm={onConfirm}
      />

      <SimpleAccordion
        summary="Delete IOC"
        defaultExpanded
      >
        <Grid
          container
          spacing={1}
        >
          {error ? (
            <Grid
              item
              xs={12}
            >
              <Alert severity="error">{error}</Alert>
            </Grid>
          ) : (
            <></>
          )}
          <Grid
            item
            xs={12}
          >
            <AccessControl
              allowedRoles={["DeploymentToolAdmin"]}
              renderNoAccess={() => (
                <Tooltip title={"Only admins can delete the IOC"}>
                  <span>
                    <Button
                      color="error"
                      variant="contained"
                      disabled
                    >
                      Delete IOC
                    </Button>
                  </span>
                </Tooltip>
              )}
            >
              <Tooltip title={disabledButtonTitle}>
                <span>
                  <Button
                    onClick={() => setOpen(true)}
                    disabled={
                      buttonDisabled ||
                      ioc.operationInProgress ||
                      ioc.activeDeployment
                    }
                    color="error"
                    variant="contained"
                  >
                    Delete IOC
                  </Button>
                </span>
              </Tooltip>
            </AccessControl>
          </Grid>
        </Grid>
      </SimpleAccordion>
    </>
  );
}
